@@ -25,6 +25,7 @@
 #include <glom/glade_utils.h>
 #include <glom/frame_glom.h> //For show_ok_dialog()
 #include <glom/utils_ui.h> //For bold_message()).
+#include <glibmm/main.h>
 #include <glibmm/i18n.h>
 
 namespace Glom
@@ -35,7 +36,7 @@ Box_Data_List_Related::Box_Data_List_Related()
   m_Alignment.add(m_AddDel);
   add_view(&m_AddDel); //Give it access to the document.
   m_AddDel.show();
-  m_AddDel.set_height_rows(5);
+  m_AddDel.set_height_rows(6, 6);
   m_Alignment.show();
 
   //Connect signals:
@@ -84,26 +85,26 @@ bool Box_Data_List_Related::init_db_details(const Glib::ustring& parent_table, b
 
   if(show_title)
   {
-    Glib::ustring relationship_title;
-    if(m_portal && m_portal->get_has_relationship_name())
-      relationship_title = m_portal->get_title_used(Glib::ustring() /* parent title - not relevant */);
-    else
-    {
-      //Note to translators: This text is shown instead of a table title, when the table has not yet been chosen.
-      relationship_title = _("Undefined Table");
-    }
+    Glib::ustring title;
+    if(m_portal)
+      title = m_portal->get_title();
 
-    m_Label.set_markup(Utils::bold_message(relationship_title));
+    m_Label.set_markup(Utils::bold_message(title));
     m_Label.show();
 
+    if(!(m_Frame.get_label_widget()))
+      m_Frame.set_label_widget(m_Label);
+
     m_Alignment.set_padding(Utils::DEFAULT_SPACING_SMALL /* top */, 0, Utils::DEFAULT_SPACING_LARGE /* left */, 0);
   }
   else
   {
     m_Label.set_markup(Glib::ustring());
     m_Label.hide();
+    if(m_Frame.get_label_widget())
+      m_Frame.unset_label(); //Otherwise the allocation is calculated wrong due to GtkFrame bug: https://bugzilla.gnome.org/show_bug.cgi?id=662915
 
-    m_Alignment.set_padding(0, 0, 0, 0); //The box itself has padding of 6.
+    m_Alignment.set_padding(0.0f, 0.0f, 0.0f, 0.0f); //The box itself has padding of 6.
   }
 
   if(m_portal)
@@ -389,9 +390,11 @@ void Box_Data_List_Related::create_layout()
   
   if(m_portal)
   {
-    const double rows_count = m_portal->get_rows_count();
-    if(rows_count) //0 is a silly value.
-      m_AddDel.set_height_rows(rows_count);
+    gulong rows_count_min = 0;
+    gulong rows_count_max = 0;
+    m_portal->get_rows_count(rows_count_min, rows_count_max);
+    if(rows_count_min) //0 is a silly value.
+      m_AddDel.set_height_rows(rows_count_min, rows_count_max);
   }
 
   sharedptr<Field> field_primary_key = get_field_primary_key_for_table(Base_DB_Table::m_table_name);
