@@ -19,13 +19,13 @@
  */
 
 #include "config.h"
-#include <gtkmm.h>
 #include "dialog_relationships_overview.h"
 #include "glom/utility_widgets/canvas/canvas_line_movable.h"
 #include "glom/utility_widgets/canvas/canvas_text_movable.h"
 #include <glom/mode_design/layout/dialog_choose_relationship.h>
 #include "printoperation_relationshipsoverview.h"
 #include "glom/application.h"
+#include <gtkmm/stock.h>
 #include <goocanvas.h>
 #include <glibmm/i18n.h>
 #include <iostream>
@@ -50,7 +50,7 @@ Dialog_RelationshipsOverview::Dialog_RelationshipsOverview(BaseObjectType* cobje
   m_refSettings = Gtk::PrintSettings::create();
 
   //Add a menu:
-  Gtk::VBox* vbox = 0;
+  Gtk::Box* vbox = 0;
   builder->get_widget("vbox_placeholder_menubar", vbox);
 
   m_refActionGroup = Gtk::ActionGroup::create();
@@ -75,11 +75,7 @@ Dialog_RelationshipsOverview::Dialog_RelationshipsOverview(BaseObjectType* cobje
   {
     static const Glib::ustring ui_description =
     "<ui>"
-#ifdef GLOM_ENABLE_MAEMO
-    "  <popup name='Overview_MainMenu'>"
-#else
     "  <menubar name='Overview_MainMenu'>"
-#endif
     "    <menu action='Overview_MainMenu_File'>"
     "      <menuitem action='Overview_MainMenu_File_PageSetup' />"
     "      <menuitem action='Overview_MainMenu_File_Print' />"
@@ -87,11 +83,7 @@ Dialog_RelationshipsOverview::Dialog_RelationshipsOverview(BaseObjectType* cobje
     "    <menu action='Overview_MainMenu_View'>"
     "      <menuitem action='Overview_MainMenu_View_Grid' />"
     "    </menu>"
-#ifdef GLOM_ENABLE_MAEMO
-    "  </popup>"
-#else
     "  </menubar>"
-#endif
     "</ui>";
 
     m_refUIManager->add_ui_from_string(ui_description);
@@ -205,13 +197,12 @@ void Dialog_RelationshipsOverview::draw_tables()
       Glib::RefPtr<CanvasGroupDbTable> table_group =
         CanvasGroupDbTable::create(info->get_name(), info->get_title_or_name(), fields, table_x, table_y);
       m_group_tables->add_child(table_group);
+      m_canvas.associate_with_grid(table_group); //Make snapping work.
 
-      sigc::connection the_connection = table_group->signal_moved().connect( sigc::bind(
-        sigc::mem_fun(*this, &Dialog_RelationshipsOverview::on_table_moved),
-        table_group) );
-      m_list_table_connections.push_back(the_connection);
+      table_group->signal_moved().connect(
+        sigc::mem_fun(*this, &Dialog_RelationshipsOverview::on_table_moved));
 
-      the_connection = table_group->signal_show_context().connect( sigc::bind(
+      sigc::connection the_connection = table_group->signal_show_context().connect( sigc::bind(
         sigc::mem_fun(*this, &Dialog_RelationshipsOverview::on_table_show_context),
         table_group) );
       m_list_table_connections.push_back(the_connection);
@@ -329,7 +320,7 @@ void Dialog_RelationshipsOverview::draw_lines()
           Glib::RefPtr<CanvasTextMovable> text = CanvasTextMovable::create(relationship->get_title_or_name(),
             text_x, text_y, -1, //TODO: Calc a suitable width.
             Goocanvas::ANCHOR_CENTER);
-          text->property_font() = "sans 10";
+          text->property_font() = "Sans 10";
           text->property_use_markup() = true;
           text->set_movement_allowed(false, false); //Move only as part of the parent group.
           m_group_lines->add_child(text);
@@ -377,12 +368,10 @@ void Dialog_RelationshipsOverview::on_menu_view_showgrid()
 {
   if(m_action_showgrid->get_active())
   {
-    std::cout << "showing" << std::endl;
     m_canvas.set_grid_gap(40);
   }
   else
   {
-    std::cout << "hiding" << std::endl;
     m_canvas.remove_grid();
   }
 }
@@ -434,8 +423,13 @@ Glib::RefPtr<CanvasGroupDbTable> Dialog_RelationshipsOverview::get_table_group(c
   return Glib::RefPtr<CanvasGroupDbTable>();
 }
 
-void Dialog_RelationshipsOverview::on_table_moved(Glib::RefPtr<CanvasGroupDbTable> table)
+void Dialog_RelationshipsOverview::on_table_moved(const Glib::RefPtr<CanvasItemMovable>& item, double /* x_offset */, double /* y_offset */)
 {
+  Glib::RefPtr<CanvasGroupDbTable> table = 
+    Glib::RefPtr<CanvasGroupDbTable>::cast_dynamic(item);
+  if(!table)
+    return;
+
   Document* document = dynamic_cast<Document*>(get_document());
   if(document && table)
   {
