@@ -17,8 +17,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-
-//We include this at the top to use a temporary GTKMM_MAEMO_EXTENSIONS_ENABLED-related fix. 
+ 
 #include <glom/application.h> // For get_application().
 
 #include "canvas_image_movable.h"
@@ -72,24 +71,14 @@ Glib::RefPtr<CanvasImageMovable> CanvasImageMovable::create(double x, double y)
 
 void CanvasImageMovable::get_xy(double& x, double& y) const
 {
-#ifdef GLIBMM_PROPERTIES_ENABLED
   x = property_x();
   y = property_y();
-#else
-  get_property("x", x);
-  get_property("y", y);
-#endif
 }
 
 void CanvasImageMovable::set_xy(double x, double y)
 {
-#ifdef GLIBMM_PROPERTIES_ENABLED
   property_x() = x;
   property_y() = y;
-#else
-  set_property("x", x);
-  set_property("y", y);
-#endif
 }
 
 void CanvasImageMovable::get_width_height(double& width, double& height) const
@@ -97,24 +86,14 @@ void CanvasImageMovable::get_width_height(double& width, double& height) const
   //TODO: This only works when it is on a canvas already,
   //and this is apparently incorrect when the "coordinate space" of the item changes, whatever that means. murrayc.
   
-#ifdef GLIBMM_PROPERTIES_ENABLED
   width = property_width();
   height = property_height();
-#else
-  get_property("width", width);
-  get_property("height", height);
-#endif 
 }
 
 void CanvasImageMovable::set_width_height(double width, double height)
 {
-#ifdef GLIBMM_PROPERTIES_ENABLED
   property_width() = width;
   property_height() = height;
-#else
-  set_property("width", width);
-  set_property("height", height);
-#endif 
 }
 
 void CanvasImageMovable::snap_position(double& x, double& y) const
@@ -133,11 +112,7 @@ void CanvasImageMovable::snap_position(double& x, double& y) const
       corner_y_offset = 0;
       break;
     case CORNER_TOP_RIGHT:
-#ifdef GLIBMM_PROPERTIES_ENABLED    
       corner_x_offset = property_width();
-#else
-      get_property("width", corner_x_offset);
-#endif      
       corner_y_offset = 0;
       break;
     case CORNER_BOTTOM_LEFT:
@@ -180,11 +155,7 @@ void CanvasImageMovable::set_snap_corner(Corners corner)
 
 void CanvasImageMovable::set_image(const Glib::RefPtr<Gdk::Pixbuf>& pixbuf, bool scale)
 {
-#ifdef GLIBMM_PROPERTIES_ENABLED
   property_pixbuf() = pixbuf;
-#else
-  set_property("pixbuf", pixbuf);
-#endif    
   m_pixbuf = pixbuf;
 
   if(scale)
@@ -201,20 +172,31 @@ void CanvasImageMovable::scale_to_size()
   double width = 0;
   double height = 0;
   get_width_height(width, height);
-  //std::cout << "CanvasImageMovable::set_image(): width=" << width << ", height=" << height << std::endl;
-  
-  if(width && height)
+  Goocanvas::Canvas* canvas = get_canvas();
+  if(!canvas)
   {
-    Glib::RefPtr<Gdk::Pixbuf> pixbuf = Utils::image_scale_keeping_ratio(m_pixbuf, (int)height, (int)width);
-#ifdef GLIBMM_PROPERTIES_ENABLED
+    std::cerr << G_STRFUNC << ": canvas is null" << std::endl;
+    return;
+  }
+  
+  //Convert, because our canvas uses units (mm) but the pixbuf uses pixels:
+  double width_pixels = width;
+  double height_pixels = height;
+  canvas->convert_to_pixels(width_pixels, height_pixels);
+
+  if(width_pixels && height_pixels)
+  {
+    Glib::RefPtr<Gdk::Pixbuf> pixbuf = Utils::image_scale_keeping_ratio(m_pixbuf, (int)height_pixels, (int)width_pixels);
     property_pixbuf() = pixbuf;
-#else
-    set_property("pixbuf", pixbuf);
-#endif 
   }
 
   //Make sure that the size stays the same even if the scaling wasn't exact:
   set_width_height(width, height);
+  
+  //TODO: Fix this goocanvas bug http://bugzilla.gnome.org/show_bug.cgi?id=657592, 
+  //We can't work around it by forcing an extra scale in GooCanvasItem like so:
+  //property_scale_to_fit() = true;
+  //because that does not keep the aspect ratio.
 }
 
 void CanvasImageMovable::set_image_empty()
@@ -229,12 +211,8 @@ void CanvasImageMovable::set_image_empty()
 
   Glib::RefPtr<Gdk::Pixbuf> pixbuf;
   if(widget)
-    pixbuf = widget->render_icon(Gtk::Stock::MISSING_IMAGE, Gtk::ICON_SIZE_DIALOG);
-#ifdef GLIBMM_PROPERTIES_ENABLED
+    pixbuf = widget->render_icon_pixbuf(Gtk::Stock::MISSING_IMAGE, Gtk::ICON_SIZE_DIALOG);
     property_pixbuf() = pixbuf;
-#else
-    set_property("pixbuf", pixbuf);
-#endif
 }
 
 bool CanvasImageMovable::get_image_empty() const
